@@ -2,13 +2,13 @@ package Business::Tax::US::Form_1040::Worksheets;
 use 5.14.0;
 use warnings;
 use Carp;
-use Data::Dump qw(dd pp);
+#use Data::Dump qw(dd pp);
 
 BEGIN {
     use Exporter ();
     use List::Util qw( min );
     our ($VERSION, @ISA, @EXPORT_OK);
-    $VERSION     = '0.05';
+    $VERSION     = '0.06';
     @ISA         = qw(Exporter);
     @EXPORT_OK   = qw(
         social_security_benefits
